@@ -1,4 +1,5 @@
 #!/usr/bin/perl -w
+# Compile rule6.yp first: eyapp Rule6.yp
 # foldrule6.pl
 use strict;
 use Rule6;
@@ -10,6 +11,7 @@ sub set_terminfo {
   no warnings;
   *TERMINAL::info = sub { $_[0]{attr} };
 }
+
 sub is_foldable {
   my ($op, $left, $right);
   return 0 unless defined($op = $BinaryOperation{ref($_[0])});
@@ -24,11 +26,17 @@ sub is_foldable {
 
 my $parser = new Rule6();
 my $input = "2*3";
-my $t = $parser->Run(\$input);
+$parser->input(\$input);
+my $t = $parser->YYParse;
+
+exit(1) if $parser->YYNberr > 0;
+
 &set_terminfo;
 print "\n***** Before ******\n";
 print $t->str;
+
 my $p = Parse::Eyapp::YATW->new(PATTERN => \&is_foldable);
 $p->s($t);
+
 print "\n***** After ******\n";
 print $t->str."\n";
