@@ -127,12 +127,18 @@ EORT
       my $parser = $termdef{$t}[3][0];
       $reg =~ s{^/}{/\\G}; # add \G at the begining of the regexp
       $DEFINEDTOKENS .= << "EORT";
-      my \$pos = pos();
+      \$pos = pos();
       if (${reg}gc) { 
         if (\$self->expects('$t')) {   
+           my \$oldselfpos = \$self->{POS};
+           \$self->{POS} = pos();   
            if (\$self->YYPreParse('$parser')) {
+             \$self->{POS} = \$oldselfpos;
              return ('$t', \$1); 
            }
+           else {
+             \$self->{POS} = \$oldselfpos;
+           }
         }
       }
       pos(\$_) = \$pos;
@@ -142,13 +148,20 @@ EORT
       my $reg = $termdef{$t}[0];
       my $parser = $termdef{$t}[3][0];
       $reg =~ s{^/}{/\\G}; # add \G at the begining of the regexp
+      # factorize, factorize!!!! ohh!!!!
       $DEFINEDTOKENS .= << "EORT";
-      my \$pos = pos();
+      \$pos = pos();
       if (${reg}gc) { 
         if (\$self->expects('$t')) {   
+           my \$oldselfpos = \$self->{POS};
+           \$self->{POS} = pos();   
            if (!\$self->YYPreParse('$parser')) {
+             \$self->{POS} = \$oldselfpos;
              return ('$t', \$1); 
            }
+           else {
+             \$self->{POS} = \$oldselfpos;
+           }
         }
       }
       pos(\$_) = \$pos;
@@ -201,6 +214,7 @@ sub _lexerFrame {
 # Default lexical analyzer
 our $LEX = sub {
     my $self = shift;
+    my $pos;
 
     for (${$self->input}) {
       <<INCREMENTAL>>
